@@ -11,11 +11,20 @@ DESCRIPTION = '''goto function's start
 EXAMPLE:
     0x00000000: push {r4-r7, lr} -> function's prolog
     ...
-    0x000000f0: push {r4-r7, pc} -> function's epilog
+    0x000000f0: pop {r4-r7, pc} -> function's epilog
 
     results = [0xf0]
     -> function-start
     result = [0]
+
+EXAMPLE 2:
+    0x00000000: push {r4-r7, lr} -> function's prolog
+    ...
+    0x000000f0: pop {r4-r7, pc} -> function's epilog
+
+    results = []
+    -> function-start arm-find-all 'pop {r4-r7, pc}'
+    result = [0]
 '''
 
 
@@ -30,6 +39,7 @@ def get_parser():
     p = utils.ArgumentParserNoExit('function-start',
                                    description=DESCRIPTION,
                                    formatter_class=RawTextHelpFormatter)
+    p.add_argument('cmd', nargs='*', default='', help='command')
     return p
 
 
@@ -43,4 +53,10 @@ def function_start(addresses):
 
 
 def run(segments, args, addresses, interpreter=None, **kwargs):
+    if len(args.cmd) > 0:
+        cmd = args.cmd[0] + ' ' + \
+              ''.join('"{}"'.format(c) for c in args.cmd[1:])
+        addresses = interpreter.find_from_instructions_list(
+            [cmd],
+            addresses=addresses)
     return list(function_start(addresses))
