@@ -35,6 +35,7 @@ class FaInterp:
         self._segments = OrderedDict()
         self._signatures_root = DEFAULT_SIGNATURES_ROOT
         self._symbols = {}
+        self._consts = {}
         self.history = []
         self.checkpoints = {}
         self.endianity = '<'
@@ -146,7 +147,6 @@ class FaInterp:
     def symbols(self):
         """
         Run find for all SIG files in currently active project
-        :param output_file_path: optional, save found symbols into output file
         :return: dictionary of found symbols
         """
         self.get_python_symbols()
@@ -371,6 +371,7 @@ class FaInterp:
         :return: Addresses of matching signatures.
         :rtype: result list of last returns instruction
         """
+        self.log('interpreting SIG for: {}'.format(signature_json['name']))
         return self.find_from_instructions_list(
             signature_json['instructions'], decremental)
 
@@ -404,7 +405,7 @@ class FaInterp:
         sys.path.append(project_root)
 
         for root, dirs, files in os.walk(project_root):
-            for filename in files:
+            for filename in sorted(files):
                 if not filename.lower().endswith('.py'):
                     continue
 
@@ -427,7 +428,7 @@ class FaInterp:
         project_root = os.path.join(self._signatures_root, self._project)
 
         for root, dirs, files in os.walk(project_root):
-            for filename in files:
+            for filename in sorted(files):
                 if not filename.lower().endswith('.sig'):
                     continue
 
@@ -444,9 +445,15 @@ class FaInterp:
 
         return signatures
 
+    def set_const(self, name, value):
+        self._consts[name] = value
+
     def set_symbol(self, symbol_name, value):
         self._symbols[symbol_name] = value
 
+    def get_consts(self):
+        return self._consts
+
     def find(self, symbol_name, decremental=False):
         """
         Find symbol by its name in the SIG file
