@@ -1,4 +1,5 @@
 import binascii
+import re
 import traceback
 from collections import namedtuple
 import subprocess
@@ -20,7 +21,7 @@ import ida_pro
 import idaapi
 import idc
 
-from fa import fainterp
+from fa import fainterp, fa_types
 
 # Filename for the temporary created signature
 TEMP_SIG_FILENAME = os.path.join(tempfile.gettempdir(), 'fa_tmp_sig.sig')
@@ -88,7 +89,6 @@ class IdaLoader(fainterp.FaInterp):
 
         signature = {
             'name': idc.get_func_name(current_ea),
-            'type': 'function',
             'instructions': []
         }
 
@@ -156,12 +156,6 @@ class IdaLoader(fainterp.FaInterp):
             # if remote sig has a proper name, but current one is not
             ida_kernwin.jumpto(results[0])
 
-            if not sig['name'].startswith('sub_') and \
-                    idc.get_func_name(results[0]).startswith('sub_'):
-                if ida_kernwin.ask_yn(1, 'Only one result has been found. '
-                                         'Rename?') == 1:
-                    idc.set_name(results[0], str(sig['name']), idc.SN_CHECK)
-
     def verify_project(self):
         """
         Verify a valid project is currently active.
@@ -235,14 +229,16 @@ class IdaLoader(fainterp.FaInterp):
                 results[name] = ea
                 output += '{} = 0x{:08x};\n'.format(name, ea)
 
-        print(output)
-
         if filename is not None:
             with open(filename, 'w') as f:
                 f.write(output)
 
         return results
 
+    def set_const(self, name, value):
+        super(IdaLoader, self).set_const(name, value)
+        fa_types.add_const(name, value)
+
     def set_symbol(self, symbol_name, value):
         super(IdaLoader, self).set_symbol(symbol_name, value)
         idc.set_name(value, symbol_name, idc.SN_CHECK)
@@ -293,6 +289,7 @@ class IdaLoader(fainterp.FaInterp):
                               {StringLabel}
                               <#Symbols#Symbols filename:{iSymbolsFilename}>
                               <#C Header#C Header filename:{iHeaderFilename}>
+                              <#ifdef_macro#ifdef'ed:{iIfdef}>
                               <#Select dir#Browse for dir:{iDir}>
                               """, {
                                   'iDir': Form.DirInput(),
@@ -302,8 +299,9 @@ class IdaLoader(fainterp.FaInterp):
                                   'iSymbolsFilename': Form.StringInput(
                                       value='symbols.txt'),
                                   'iHeaderFilename': Form.StringInput(
-                                      value='header.h')
-
+                                      value='fa_structs.h'),
+                                  'iIfdef': Form.StringInput(
+                                      value='FA_STRUCTS'),
                               })
                 self.__n = 0
 
@@ -327,15 +325,43 @@ class IdaLoader(fainterp.FaInterp):
             c_header_filename = os.path.join(form.iDir.value,
                                              form.iHeaderFilename.value)
 
+            consts_ordinal = None
             ordinals = []
             for ordinal in range(1, ida_typeinf.get_ordinal_qty(idati) + 1):
                 ti = ida_typeinf.tinfo_t()
                 if ti.get_numbered_type(idati, ordinal):
-                    ordinals.append(str(ordinal))
-                    # print ordinal, ti
+                    if ti.get_type_name() == 'FA_CONSTS':
+                        # convert into macro definitions
+                        consts_ordinal = ordinal
+                    else:
+                        ordinals.append(str(ordinal))
 
             with open(c_header_filename, 'w') as f:
-                f.write(idc.print_decls(','.join(ordinals), 0))
+                ifdef_name = form.iIfdef.value.strip()
+
+                if len(ifdef_name) > 0:
+                    f.write('#ifdef {}\n\n'.format(ifdef_name))
+
+                if consts_ordinal is not None:
+                    consts = re.findall('\s*(.+?) = (.+?),',
+                                        idc.print_decls(
+                                            str(consts_ordinal), 0))
+                    for k, v in consts:
+                        f.write('#define {} ({})\n'.format(k, v))
+                    f.write('\n')
+
+                structs_buf = idc.print_decls(','.join(ordinals), 0)
+
+                for struct_name in re.findall('struct (.+?)\s+\{', structs_buf):
+                    f.write('typedef struct {struct_name} {struct_name};\n'
+                            .format(struct_name=struct_name))
+                f.write('\n')
+                f.write(structs_buf)
+                f.write('\n')
+
+                if len(ifdef_name) > 0:
+                    f.write('#endif // {ifdef_name}\n'
+                            .format(ifdef_name=ifdef_name))
 
         form.Free()
 
